import { useCallback, useEffect, useState, } from "react";
import { useEventCallback, useEventListener } from "usehooks-ts";
function useLocalStorage(key, initialValue) {
    var readValue = useCallback(function () {
        if (typeof window === "undefined") {
            return initialValue;
        }
        try {
            var item = window.localStorage.getItem(key);
            return item ? JSON.parse(item) : initialValue;
        }
        catch (error) {
            console.warn("Error reading localStorage key \u201C".concat(key, "\u201D:"), error);
            return initialValue;
        }
    }, [initialValue, key]);
    var _a = useState(readValue), storedValue = _a[0], setStoredValue = _a[1];
    var setValue = useEventCallback(function (value) {
        // Prevent build error "window is undefined" but keeps working
        if (typeof window === "undefined") {
            console.warn("Tried setting localStorage key \u201C".concat(key, "\u201D even though environment is not a client"));
        }
        try {
            var newValue = value instanceof Function ? value(storedValue) : value;
            window.localStorage.setItem(key, JSON.stringify(newValue));
            setStoredValue(newValue);
            window.dispatchEvent(new Event("local-storage"));
        }
        catch (error) {
            console.warn("Error setting localStorage key \u201C".concat(key, "\u201D:"), error);
        }
    });
    useEffect(function () {
        setStoredValue(readValue());
    }, []);
    var handleStorageChange = useCallback(function (event) {
        if ((event === null || event === void 0 ? void 0 : event.key) && event.key !== key) {
            return;
        }
        setStoredValue(readValue());
    }, [key, readValue]);
    useEventListener("storage", handleStorageChange);
    useEventListener("local-storage", handleStorageChange);
    return [storedValue, setValue];
}
export default useLocalStorage;
